Tok

Enum Tok 

pub enum Tok {
Show 46 variants Match, Where, Return, Order, By, Skip, Limit, As, And, Or, Not, Asc, Desc, With, Unwind, Optional, Create, Set, Delete, Detach, Merge, Ident(String), Str(String), Int(i64), Float(f64), Param(String), LParen, RParen, LBracket, RBracket, LBrace, RBrace, Colon, Pipe, Comma, Dot, Eq, Ne, Lt, Le, Gt, Ge, Dash, Star, Plus, Slash,
}

Variants



Match



Where



Return



Order



By



Skip



Limit



As



And



Or



Not



Asc



Desc



With



Unwind



Optional

OPTIONAL — marks the start of an OPTIONAL MATCH clause.



Create



Set



Delete



Detach



Merge



Ident(String)



Str(String)



Int(i64)



Float(f64)



Param(String)



LParen



RParen



LBracket



RBracket



LBrace



RBrace



Colon



Pipe

| — relationship-type alternation in a pattern ([:A|:B]).



Comma



Dot



Eq



Ne



Lt



Le



Gt



Ge



Dash



Star

* — used in COUNT(*) and multiplication.



Plus

+ — addition operator.



Slash

/ — division operator.